from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class IdentifierTypeCodesCode(GenericTypeCode):
    """
    Identifier Type Codes
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
        A coded type for an identifier that can be used to determine which identifier
    to use for a specific purpose.
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://terminology.hl7.org/CodeSystem/v2-0203
    """
    codeset: FhirUri = "http://terminology.hl7.org/CodeSystem/v2-0203"


class IdentifierTypeCodesCodeValues:
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """

    AccreditationcertificationIdentifier = IdentifierTypeCodesCode("AC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AccessionId = IdentifierTypeCodesCode("ACSN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AmericanExpress = IdentifierTypeCodesCode("AM")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AmericanMedicalAssociationNumber = IdentifierTypeCodesCode("AMA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AccountNumber = IdentifierTypeCodesCode("AN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AccountNumberCreditor = IdentifierTypeCodesCode("ANC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AccountNumberDebitor = IdentifierTypeCodesCode("AND")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AnonymousIdentifier = IdentifierTypeCodesCode("ANON")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TemporaryAccountNumber = IdentifierTypeCodesCode("ANT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AdvancedPracticeRegisteredNurseNumber = IdentifierTypeCodesCode("APRN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    AncestorSpecimenId = IdentifierTypeCodesCode("ASID")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BankAccountNumber = IdentifierTypeCodesCode("BA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BankCardNumber = IdentifierTypeCodesCode("BC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BirthCertificateFileNumber = IdentifierTypeCodesCode("BCFN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BirthCertificate = IdentifierTypeCodesCode("BCT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BirthRegistryNumber = IdentifierTypeCodesCode("BR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    BreedRegistryNumber = IdentifierTypeCodesCode("BRN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PrimaryPhysicianOfficeNumber = IdentifierTypeCodesCode("BSNR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    CostCenterNumber = IdentifierTypeCodesCode("CC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ChangeOfNameDocument = IdentifierTypeCodesCode("CONM")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    CountyNumber = IdentifierTypeCodesCode("CY")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    CitizenshipCard = IdentifierTypeCodesCode("CZ")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DeathCertificateId = IdentifierTypeCodesCode("DC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DeathCertificateFileNumber = IdentifierTypeCodesCode("DCFN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DentistLicenseNumber = IdentifierTypeCodesCode("DDS")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DrugEnforcementAdministrationRegistrationNumber = IdentifierTypeCodesCode("DEA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DrugFurnishingOrPrescriptiveAuthorityNumber = IdentifierTypeCodesCode("DFN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DinersClubCard = IdentifierTypeCodesCode("DI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DriversLicenseNumber = IdentifierTypeCodesCode("DL")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DoctorNumber = IdentifierTypeCodesCode("DN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    OsteopathicLicenseNumber = IdentifierTypeCodesCode("DO")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DiplomaticPassport = IdentifierTypeCodesCode("DP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PodiatristLicenseNumber = IdentifierTypeCodesCode("DPM")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DonorRegistrationNumber = IdentifierTypeCodesCode("DR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    DiscoverCard = IdentifierTypeCodesCode("DS")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    EmployeeNumber = IdentifierTypeCodesCode("EI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    EmployerNumber = IdentifierTypeCodesCode("EN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    StaffEnterpriseNumber = IdentifierTypeCodesCode("ESN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    FetalDeathReportId = IdentifierTypeCodesCode("FDR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    FetalDeathReportFileNumber = IdentifierTypeCodesCode("FDRFN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    FacilityId = IdentifierTypeCodesCode("FI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    FillerIdentifier = IdentifierTypeCodesCode("FILL")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    GuarantorInternalIdentifier = IdentifierTypeCodesCode("GI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    GeneralLedgerNumber = IdentifierTypeCodesCode("GL")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    GuarantorExternalIdentifier = IdentifierTypeCodesCode("GN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    HealthCardNumber = IdentifierTypeCodesCode("HC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    Indigenousaboriginal = IdentifierTypeCodesCode("IND")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    JurisdictionalHealthNumbercanada = IdentifierTypeCodesCode("JHN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LaboratoryAccessionId = IdentifierTypeCodesCode("LACSN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LifelongPhysicianNumber = IdentifierTypeCodesCode("LANR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LaborAndIndustriesNumber = IdentifierTypeCodesCode("LI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LicenseNumber = IdentifierTypeCodesCode("LN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LocalRegistryId = IdentifierTypeCodesCode("LR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PatientMedicaidNumber = IdentifierTypeCodesCode("MA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MemberNumber = IdentifierTypeCodesCode("MB")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PatientsMedicareNumber = IdentifierTypeCodesCode("MC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PractitionerMedicaidNumber = IdentifierTypeCodesCode("MCD")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MicrochipNumber = IdentifierTypeCodesCode("MCN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PractitionerMedicareNumber = IdentifierTypeCodesCode("MCR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MarriageCertificate = IdentifierTypeCodesCode("MCT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MedicalLicenseNumber = IdentifierTypeCodesCode("MD")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MilitaryIdNumber = IdentifierTypeCodesCode("MI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MedicalRecordNumber = IdentifierTypeCodesCode("MR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TemporaryMedicalRecordNumber = IdentifierTypeCodesCode("MRT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    Mastercard = IdentifierTypeCodesCode("MS")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SecondaryPhysicianOfficeNumber = IdentifierTypeCodesCode("NBSNR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NaturalizationCertificate = IdentifierTypeCodesCode("NCT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalEmployerIdentifier = IdentifierTypeCodesCode("NE")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalHealthPlanIdentifier = IdentifierTypeCodesCode("NH")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalUniqueIndividualIdentifier = IdentifierTypeCodesCode("NI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalInsuranceOrganizationIdentifier = IdentifierTypeCodesCode("NII")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalInsurancePayorIdentifierpayor = IdentifierTypeCodesCode("NIIP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalPersonIdentifierWhereTheXxxIsTheIsoTable31663characteralphabeticCountryCode = IdentifierTypeCodesCode(
        "NNxxx"
    )
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NursePractitionerNumber = IdentifierTypeCodesCode("NP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    NationalProviderIdentifier = IdentifierTypeCodesCode("NPI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ObservationInstanceIdentifier = IdentifierTypeCodesCode("OBI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    OptometristLicenseNumber = IdentifierTypeCodesCode("OD")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PhysicianAssistantNumber = IdentifierTypeCodesCode("PA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ParoleCard = IdentifierTypeCodesCode("PC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PenitentiarycorrectionalInstitutionNumber = IdentifierTypeCodesCode("PCN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    LivingSubjectEnterpriseNumber = IdentifierTypeCodesCode("PE")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PensionNumber = IdentifierTypeCodesCode("PEN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PublicHealthCaseIdentifier = IdentifierTypeCodesCode("PHC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PublicHealthEventIdentifier = IdentifierTypeCodesCode("PHE")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PublicHealthOfficialId = IdentifierTypeCodesCode("PHO")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PatientInternalIdentifier = IdentifierTypeCodesCode("PI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PlacerIdentifier = IdentifierTypeCodesCode("PLAC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PersonNumber = IdentifierTypeCodesCode("PN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TemporaryLivingSubjectNumber = IdentifierTypeCodesCode("PNT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MedicarecmsPerformingProviderIdentificationNumber = IdentifierTypeCodesCode("PPIN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PassportNumber = IdentifierTypeCodesCode("PPN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PermanentResidentCardNumber = IdentifierTypeCodesCode("PRC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ProviderNumber = IdentifierTypeCodesCode("PRN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PatientExternalIdentifier = IdentifierTypeCodesCode("PT")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    QaNumber = IdentifierTypeCodesCode("QA")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ResourceIdentifier = IdentifierTypeCodesCode("RI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    RegisteredNurseNumber = IdentifierTypeCodesCode("RN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    PharmacistLicenseNumber = IdentifierTypeCodesCode("RPH")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    RailroadRetirementNumber = IdentifierTypeCodesCode("RR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    RegionalRegistryId = IdentifierTypeCodesCode("RRI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    RailroadRetirementProvider = IdentifierTypeCodesCode("RRP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SocialBeneficiaryIdentifier = IdentifierTypeCodesCode("SB")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SpecimenId = IdentifierTypeCodesCode("SID")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    StateLicense = IdentifierTypeCodesCode("SL")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SubscriberNumber = IdentifierTypeCodesCode("SN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    StateAssignedNdbsCardIdentifier = IdentifierTypeCodesCode("SNBSN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SerialNumber = IdentifierTypeCodesCode("SNO")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    StudyPermit = IdentifierTypeCodesCode("SP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    StateRegistryId = IdentifierTypeCodesCode("SR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    SocialSecurityNumber = IdentifierTypeCodesCode("SS")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    ShipmentTrackingNumber = IdentifierTypeCodesCode("STN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TaxIdNumber = IdentifierTypeCodesCode("TAX")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TreatyNumbercanada = IdentifierTypeCodesCode("TN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TemporaryPermanentResidentcanada = IdentifierTypeCodesCode("TPR")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    TrainingLicenseNumber = IdentifierTypeCodesCode("TRL")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    UnspecifiedIdentifier = IdentifierTypeCodesCode("U")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    UniversalDeviceIdentifier = IdentifierTypeCodesCode("UDI")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    MedicarecmsformerlyHcfasUniversalPhysicianIdentificationNumbers = (
        IdentifierTypeCodesCode("UPIN")
    )
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    UniqueSpecimenId = IdentifierTypeCodesCode("USID")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    VisitNumber = IdentifierTypeCodesCode("VN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    VisitorPermit = IdentifierTypeCodesCode("VP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    Visa = IdentifierTypeCodesCode("VS")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    WicIdentifier = IdentifierTypeCodesCode("WC")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    WorkersCompNumber = IdentifierTypeCodesCode("WCN")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    WorkPermit = IdentifierTypeCodesCode("WP")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    HealthPlanIdentifier = IdentifierTypeCodesCode("XV")
    """
    From: http://terminology.hl7.org/CodeSystem/v2-0203 in v2-tables.xml
    """
    OrganizationIdentifier = IdentifierTypeCodesCode("XX")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    DL = IdentifierTypeCodesCode("DL")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    PPN = IdentifierTypeCodesCode("PPN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    BRN = IdentifierTypeCodesCode("BRN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    MR = IdentifierTypeCodesCode("MR")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    MCN = IdentifierTypeCodesCode("MCN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    EN = IdentifierTypeCodesCode("EN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    TAX = IdentifierTypeCodesCode("TAX")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    NIIP = IdentifierTypeCodesCode("NIIP")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    PRN = IdentifierTypeCodesCode("PRN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    MD = IdentifierTypeCodesCode("MD")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    DR = IdentifierTypeCodesCode("DR")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    ACSN = IdentifierTypeCodesCode("ACSN")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    UDI = IdentifierTypeCodesCode("UDI")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    SNO = IdentifierTypeCodesCode("SNO")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    SB = IdentifierTypeCodesCode("SB")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    PLAC = IdentifierTypeCodesCode("PLAC")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    FILL = IdentifierTypeCodesCode("FILL")
    """
    From: http://hl7.org/fhir/ValueSet/identifier-type in valuesets.xml
    """
    JHN = IdentifierTypeCodesCode("JHN")
